# How to reduce ParaView CMake configure time?

**URL:** https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100
**Category:** Development
**Created:** [July 22, 2024, 9:06am UTC](https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100 "2024-07-22T09:06:33Z")
**Posts on this page:** 4
**Page:** 1

<div class="post-metadata">

### Author: ![joint](https://discourse.paraview.org/letter_avatar_proxy/v4/letter/j/dc4da7/32.png) [@joint](https://discourse.paraview.org/u/joint)
#### Post date: [July 22, 2024, 9:06am UTC](https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100/1 "2024-07-22T09:06:33Z")

</div>

Hello, dear ParaView developers

Could you please give me an advise on how to reduce CMake configure time?  
It costs me 30s every time I modify any of CMakeLists files

Thanks

---

<div class="post-metadata">

### Author: ![cory.quammen](https://discourse.paraview.org/user_avatar/discourse.paraview.org/cory.quammen/32/11193_2.png) [@cory.quammen](https://discourse.paraview.org/u/cory.quammen)
#### Post date: [July 22, 2024, 10:53am UTC](https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100/2 "2024-07-22T10:53:13Z")

</div>

ParaView is a large project and it takes CMake some time to configure it. Unfortunately, the best way I have found is to try to make all the CMake changes that are needed and only configure again when I think I am done.

---

<div class="post-metadata">

### Author: ![ben.boeckel](https://discourse.paraview.org/letter_avatar_proxy/v4/letter/b/ea5d25/32.png) [@ben.boeckel](https://discourse.paraview.org/u/ben.boeckel)
#### Post date: [July 22, 2024, 4:54pm UTC](https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100/3 "2024-07-22T16:54:50Z")

</div>

30 seconds sounds long to me. Initial configures take about 2 minutes and I really feel like a lot more than 75% of that time is spent in `try_compile` (which should be done only once for each test). A random build I have laying around takes about 6 seconds.

Some questions:

- What platform are you on?
- What generator are you using?
- What version of CMake are you using?
- Is it the configure or generate step that is taking more time (modern CMake reports times for each, though 3.30+ have more accurate times)

---

<div class="post-metadata">

### Author: ![Massimiliano\_Leoni](https://discourse.paraview.org/user_avatar/discourse.paraview.org/massimiliano_leoni/32/376_2.png) [@Massimiliano\_Leoni](https://discourse.paraview.org/u/Massimiliano_Leoni)
#### Post date: [August 7, 2024, 3:33pm UTC](https://discourse.paraview.org/t/how-to-reduce-paraview-cmake-configure-time/15100/4 "2024-08-07T15:33:42Z")

</div>

Are you using Unix Makefiles or Ninja as a generator? I observed major differences in the two but don’t quote me on that 🥷
